@@ -14,12 +14,30 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 
-### Kendall distribution
+### Kendall distribution #######################################################
 
 ## deprecated (former) Kendall distribution function K
 K <- function(u, cop, d, n.MC=0, log=FALSE){
     .Deprecated("pK") # set K to "deprecated" => throws a message
-    pK(u, cop=cop, d=d, n.MC=n.MC, log=log) # call the new function
+    pK(u, cop=cop, d=d, n.MC=n.MC, log.p=log) # call the new function
+}
+
+##' Empirical Kendall distribution function K_{n,d} as in Lemma 1 of
+##' Genest, Neslehova, Ziegel (2011)
+##'
+##' @title Empirical Kendall distribution function
+##' @param u evaluation points u in [0,1]
+##' @param x data (in IR^d) based on which K is estimated
+##' @return K_{n,d}(u)
+##' @author Marius Hofert
+##' Note: This is the empirical distribution function of a discrete radial part
+##'       and thus K_{n,d}(0) > 0. The mass at the largest value of the support
+##'       of R determines K_{n,d}(0)
+Kn <- function(u, x)
+{
+    stopifnot(0 <= u, u <= 1, (n <- nrow(x)) >= 1, (d <- ncol(x)) >= 1)
+    W <- vapply(seq_len(n), function(i) sum( colSums(t(x)<x[i,])==d ) / (n+1), NA_real_)
+    ecdf(W)(u)
 }
 
 ##' Distribution function of the Kendall distribution
@@ -31,17 +49,17 @@ K <- function(u, cop, d, n.MC=0, log=FALSE){
 ##' @param n.MC if > 0 a Monte Carlo approach is applied with sample size equal
 ##'	   to n.MC to evaluate the generator derivatives; otherwise the exact
 ##'        formula is used
-##' @param log logical indicating whether the logarithm is returned
+##' @param log.p logical indicating whether the logarithm is returned
 ##' @return Kendall distribution function at u
 ##' @author Marius Hofert
-pK <- function(u, cop, d, n.MC=0, log=FALSE)
+pK <- function(u, cop, d, n.MC=0, log.p=FALSE)
 {
     stopifnot(is(cop, "acopula"), 0 <= u, u <= 1)
     ## limiting cases
     n <- length(u)
     res <- numeric(n)
-    res[is0 <- u == 0] <- if(log) -Inf else 0
-    res[is1 <- u == 1] <- if(log) 0 else 1
+    res[is0 <- u == 0] <- if(log.p) -Inf else 0
+    res[is1 <- u == 1] <- if(log.p) 0 else 1
     not01 <- seq_len(n)[!(is0 | is1)]
     uN01 <- u[not01]
     ## computations
@@ -55,16 +73,16 @@ pK <- function(u, cop, d, n.MC=0, log=FALSE)
                 -log(n.MC) + lsum(as.matrix(ppois(d-1, V*psInv, log.p=TRUE)))
                 ## Former code: mean(ppois(d-1, V*psInv))
             }))
-            res[not01] <- if(log) lr else exp(lr)
+            res[not01] <- if(log.p) lr else exp(lr)
         }
     } else { # direct
 	if(length(not01))
 	    res[not01] <- if(d == 1) { # d == 1
-		if(log) log(uN01) else uN01 # K(u) = u
+		if(log.p) log(uN01) else uN01 # K(u) = u
 	    } else if(d == 2) { # d == 2
 		r <- uN01 + exp( cop@iPsi(uN01, theta=th, log=TRUE) -
                                  cop@absdiPsi(uN01, th, log=TRUE) ) # K(u) = u - psi^{-1}(u) / (psi^{-1})'(u)
-                if(log) log(r) else r
+                if(log.p) log(r) else r
 	    } else { # d >= 3
 		j <- seq_len(d-1)
 		lpsiI. <- cop@iPsi(uN01, theta=th, log=TRUE)
@@ -79,7 +97,7 @@ pK <- function(u, cop, d, n.MC=0, log=FALSE)
                 lx <- labsdPsi + j %*% t(lpsiI.) - lfac.j # (d-1) x n matrix
                 lx <- rbind(log(uN01), lx) # d x n matrix containing the logarithms of the summands of K
                 ls <- lsum(lx) # log(K(u))
-                if(log) ls else pmin(1, exp(ls)) # ensure we are in [0,1] {numerical inaccuracy}
+                if(log.p) ls else pmin(1, exp(ls)) # ensure we are in [0,1] {numerical inaccuracy}
 		## Former code:
 		## K2 <- function(psInv) {
 		##    labsdPsi <- unlist(lapply(j, cop@absdPsi,
@@ -150,27 +168,27 @@ qK <- function(u, cop, d, n.MC=0,
                ## Note: This is the same code as method="monoH.FC" (but with a
                ##       chosen grid)
                u.grid <- 0:128/128 # default grid
-               K.u.grid <- pK(u.grid, cop=cop, d=d, n.MC=n.MC, log=FALSE)
+               K.u.grid <- pK(u.grid, cop=cop, d=d, n.MC=n.MC, log.p=FALSE)
                ## function for root finding
                fspl <- function(x, u)
                    splinefun(u.grid, K.u.grid, method = "monoH.FC")(x) - u
                ## root finding
                vapply(uN01, function(u)
-                      uniroot(fspl, u=u, interval=c(0,u), ...)$root, 1.0)
+                      uniroot(fspl, u=u, interval=c(0,u), ...)$root, NA_real_)
 
            },
                "simple" =               # straightforward root finding
            {
                ## function for root finding
-               f <- function(t, u) pK(t, cop=cop, d=d, n.MC=n.MC, log=FALSE) - u
+               f <- function(t, u) pK(t, cop=cop, d=d, n.MC=n.MC, log.p=FALSE) - u
                ## root finding
                vapply(uN01, function(u)
-                      uniroot(f, u=u, interval=c(0,u), ...)$root, 1.)
+                      uniroot(f, u=u, interval=c(0,u), ...)$root, NA_real_)
            },
                "sort" =                 # root finding with first sorting u's
            {
                ## function for root finding
-               f <- function(t, u) pK(t, cop=cop, d=d, n.MC=n.MC, log=FALSE) - u
+               f <- function(t, u) pK(t, cop=cop, d=d, n.MC=n.MC, log.p=FALSE) - u
                ## sort u's
                ord <- order(uN01, decreasing=TRUE)
                uN01o <- uN01[ord]       # uN01 ordered in decreasing order
@@ -199,7 +217,7 @@ qK <- function(u, cop, d, n.MC=0,
                "discrete" = # evaluate K at a grid and compute approximate quantiles based on this grid
            {
                stopifnot(0 <= u.grid, u.grid <= 1)
-               K.u.grid <- pK(u.grid, cop=cop, d=d, n.MC=n.MC, log=FALSE)
+               K.u.grid <- pK(u.grid, cop=cop, d=d, n.MC=n.MC, log.p=FALSE)
                u.grid[findInterval(uN01, vec=K.u.grid,
                                    rightmost.closed=TRUE, ...)+1] # note: this gives quantiles according to the "typical" definition
            },
@@ -208,13 +226,13 @@ qK <- function(u, cop, d, n.MC=0,
                ## evaluate K at a grid
                stopifnot(0 <= u.grid, u.grid <= 1)
                K.u.grid <- pK(u.grid, cop=cop, d=d, n.MC=n.MC,
-                              log=FALSE)
+                              log.p=FALSE)
                ## function for root finding
                fspl <- function(x, u)
                    splinefun(u.grid, K.u.grid, method = "monoH.FC")(x) - u
                ## root finding
                vapply(uN01, function(u)
-                      uniroot(fspl, u=u, interval=c(0,u), ...)$root, 1.0)
+                      uniroot(fspl, u=u, interval=c(0,u), ...)$root, NA_real_)
            },
                stop("unsupported method ", method))
     res
@@ -230,10 +248,10 @@ qK <- function(u, cop, d, n.MC=0,
 ##' @param n.MC if > 0 a Monte Carlo approach is applied with sample size equal
 ##'	   to n.MC to evaluate the d-th generator derivative; otherwise the exact
 ##'        formula is used
-##' @param log logical indicating whether the logarithm of the density is returned
+##' @param log.p logical indicating whether the logarithm of the density is returned
 ##' @return Density of the Kendall distribution at u
 ##' @author Marius Hofert
-dK <- function(u, cop, d, n.MC=0, log=FALSE)
+dK <- function(u, cop, d, n.MC=0, log.p=FALSE)
 {
     stopifnot(is(cop, "acopula"), 0 < u, u < 1)
     th <- cop@theta
@@ -243,7 +261,7 @@ dK <- function(u, cop, d, n.MC=0, log=FALSE)
     psiI <- cop@iPsi(u, theta=th) # psi^{-1}(u)
     labsdPsi <- cop@absdPsi(psiI, theta=th, degree=d, n.MC=n.MC, log=TRUE) # log((-1)^d psi^{(d)}(psi^{-1}(u)))
     res <- labsdPsi-ld+(d-1)*lpsiI+lpsiIDabs
-    if(log) res else exp(res)
+    if(log.p) res else exp(res)
 }
 
 
@@ -260,7 +278,7 @@ rK <- function(n, cop, d) {
 	stopifnot(d == round(d))
 	cop <- onacopulaL(cop@name, list(cop@theta, 1L:d))
     } else if(!is(cop, c2 <- "outer_nacopula"))
-	stop(sprintf("'cop' must be \"%s\" or \"%s\"", c1,c2))
+	stop(gettextf("'cop' must be \"%s\" or \"%s\"", c1,c2), domain=NA)
 
     pCopula(rCopula(n, cop), cop)
 }
